@@ -1,6 +1,7 @@
 use super::*;
+use std::cmp::Ordering;
 
-#[derive(Clone, Eq)]
+#[derive(Clone, Eq, Ord)]
 pub struct Literal<T> {
     ///
     pub value: T,
@@ -36,3 +37,9 @@ impl<T: PartialEq> PartialEq for Literal<T> {
         self.value.eq(&other.value)
     }
 }
+
+impl<T: PartialOrd> PartialOrd for Literal<T> {
+    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
+        self.value.partial_cmp(&other.value)
+    }
+}
