@@ -1,12 +1,12 @@
 mod arith;
+mod context;
 mod display;
 mod slugify;
-mod context;
 #[cfg(feature = "lsp-types")]
 mod toc;
 
 pub use context::ContextKind;
-pub use toc::{TableOfContent, TableNode};
+pub use toc::{TableNode, TableOfContent};
 
 pub trait Slugify {
     fn slugify(&self) -> String;
@@ -14,4 +14,4 @@ pub trait Slugify {
 
 pub trait ContextAware {
     fn context_aware(&self, offset: u32) -> ContextKind;
-}
\ No newline at end of file
+}
